/*
 * DALLOC.H - header file for DALLOC.C.
 *
 * Header Dependencies:
 *
 *    -  STDLIB.H (for *alloc()/free() function prototypes, ANSI)
 *    -  STRING.H (for str*()/mem*() function prototypes, ANSI)
 *
 * $Header:   C:/fe/shared/vcs/dalloc.h_v   1.3   15 Feb 1990 10:20:36   rji  $
 *
 * $Log:   C:/fe/shared/vcs/dalloc.h_v  $
 * 
 *    Rev 1.3   15 Feb 1990 10:20:36   rji
 * Added macro definitions d_halloc() and d_hfree() to cover halloc() and
 * hfree() calls.
 * 
 *    Rev 1.2   03 Sep 1989 23:08:32   rji
 * Made declaration of debugging versions of dynamic allocation and str*()
 * and mem*() routines dependent upon whether NDEBUG is #define'd.
 * 
 *    Rev 1.1   14 Aug 1989 11:06:28   rji
 * Public functions given shorter names for portability.
 * 
 *    Rev 1.0   07 Dec 1988 23:09:32   rji
 * Initial revision.
 *
*/

#if !defined(DALLOC_H)
#define  DALLOC_H

/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
/*
   $NAME$:
         DALLOC.H Macros

  $PATHS$
       Functions\H
       Shared\Macros
       Shared\Utils
       Modules\$./FL$


   $1$

  $0$
  SYNOPSIS:
  $-1$
*/
/*-------------------------------------------------------------------------*/
/* MACROS                                                                  */
/*                                                                         */
/* Macro arguments below are interpreted as follows:                       */
/*                                                                         */
/*             es = #bytes per element to allocate                         */
/*             m  = #bytes to allocate or transfer                         */
/*             n  = #elements to allocate                                  */
/*             p  = pointer to storage to realloc, free  or copy to        */
/*             q  = pointer to storage to copy from                        */
/*                                                                         */
/*-------------------------------------------------------------------------*/

#if !defined(NDEBUG)
#define d_malloc(m)        dmalloc( (m), __FILE__, __LINE__ )
#define d_calloc(n,es)     dcalloc( (n), (es), __FILE__, __LINE__ )
#define d_halloc(n,es)     halloc( (n), (es) )
#define d_realloc(p,m)     drealloc( (p), (m), __FILE__, __LINE__ )
#define d_free(p)          dfree( (p), __FILE__, __LINE__ )
#define d_hfree(p)         hfree( (p) )
#define d_strcpy(p,q)      dstrcpy( (p), (q), __FILE__, __LINE__ )
#define d_strncpy(p,q,m)   dstrncpy( (p), (q), (m), __FILE__, __LINE__ )
#define d_memcpy(p,q,m)    dmemcpy( (p), (q), (m), __FILE__, __LINE__ )
#else
#define d_malloc(m)        malloc( (m) )
#define d_calloc(n,es)     calloc( (n), (es) )
#define d_halloc(n,es)     halloc( (n), (es) )
#define d_realloc(p,m)     realloc( (p), (m) )
#define d_free(p)          free( (p) )
#define d_hfree(p)         hfree( (p) )
#define d_strcpy(p,q)      strcpy( (p), (q) )
#define d_strncpy(p,q,m)   strncpy( (p), (q), (m) )
#define d_memcpy(p,q,m)    memcpy( (p), (q), (m) )
#endif
/*                                                                   $end$ */

/*-------------------------------------------------------------------------*/
/* PUBLIC FUNCTIONS                                                        */
/*-------------------------------------------------------------------------*/

#if !defined(NDEBUG)
void *dmalloc( size_t, char *, int );
void *dcalloc( size_t, size_t, char *, int );
void *drealloc( void *, size_t, char *, int );
void  dfree( void *, char *, int );
char *dstrcpy( char *, char *, char *, int );
char *dstrncpy( char *, char *, size_t, char *, int );
void *dmemcpy( void *, void *, size_t, char *, int );
#endif

#endif /* if !defined(DALLOC_H) */
